@@ -18,7 +18,7 @@ $m_sDefaultClass = 'DBI::Library' unless defined $DBI::Library::m_sDefaultClass;
         qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute selectTable)
     ],
 );
-$DBI::Library::VERSION = '0.62';
+$DBI::Library::VERSION = '0.65';
 $m_tbl                 = 'querys';
 $driver                = 'mysql';
 require Exporter;
@@ -174,7 +174,7 @@ sub initDB {
 }
 
 =head2 Driver()
-
+ 
 set or get the driver
 
        Driver()
@@ -193,7 +193,7 @@ sub Driver {
 
 =head2 CurrentDb()
 
-gibt die aktuelle datenbank zurück
+return the current used Database
 
 =cut
 
@@ -203,7 +203,7 @@ sub CurrentDb {
 
 =head2 CurrentHost()
 
-gibt den aktuellen host zurück
+return the current Host
 
 =cut
 
@@ -213,7 +213,7 @@ sub CurrentHost {
 
 =head2 CurrentUser()
 
-gibt den aktuellen user zurück
+gibt den aktuellen user zurueck
 
 =cut
 
@@ -223,7 +223,7 @@ sub CurrentUser {
 
 =head2 CurrentPass()
 
-gibt das aktuelle passwort zurück
+return the cruuent password word
 
 =cut
 
