@@ -3,28 +3,35 @@ use strict;
 use warnings;
 use utf8;
 use HTML::Entities;
-use vars qw( $m_dbh $m_dsn $m_sDefaultClass @EXPORT_OK @ISA %m_hFunctions  $mod_rewrite
-  $m_sServerName $m_nSecs);
+use vars qw( 
+  $m_dbh
+  $m_dsn 
+  $m_sDefaultClass 
+  @EXPORT_OK 
+  @ISA 
+  %m_hFunctions
+  $m_sServerName 
+  $m_nSecs
+);
 $m_sDefaultClass = 'DBI::Library::Database' unless defined $DBI::Library::Database::m_sDefaultClass;
 require Exporter;
 use DBI::Library qw(:all $m_dbh $m_dsn);
 @DBI::Library::Database::ISA    = qw(DBI::Library Exporter);
 @DBI::Library::Database::EXPORT = qw(useexecute);
 @DBI::Library::Database::EXPORT_OK =
-  qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver execute useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists searchDB addUser hasAcount isMember catright topicright right getAction checkPass checkSession setSid getName rss readMenu deleteMessage reply editMessage addMessage initDB rewrite  checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string);
+  qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver execute useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists addUser hasAcount isMember right getAction checkPass checkSession setSid getName initDB checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string);
 %DBI::Library::Database::EXPORT_TAGS = (
     'all' => [
-        qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver  searchDB addUser hasAcount isMember catright topicright right getAction checkPass checkSession setSid getName rss readMenu deleteMessage reply editMessage addMessage initDB tableLength tableExists  useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute rewrite checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string)
+        qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right getAction checkPass checkSession setSid getName initDB tableLength tableExists useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute  checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string)
     ],
     'dynamic' => [qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute)],
     'independent' =>
       [qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute fetch_string)],
     'lze' => [
-        qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember  catright topicright right getAction checkPass checkSession setSid getName rss readMenu deleteMessage reply editMessage addMessage rewrite checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue)
+        qw(getActionRight CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right getAction checkPass checkSession setSid getName checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetTypes GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue)
     ],
 );
-$DBI::Library::Database::VERSION = '0.62';
-$mod_rewrite                     = 0;
+$DBI::Library::Database::VERSION = '0.65';
 $m_nSecs                         = 10;
 
 =head1 NAME
@@ -35,6 +42,10 @@ DBI::Library::Database - Database interface for MySQL::Admin::GUI
 
 use DBI::Library::Database;
 
+=head2 new()
+
+      constructor
+
 =cut
 
 sub new
@@ -46,277 +57,6 @@ sub new
     return $self;
 }
 
-=head2 addMessage
-
-     my %message = (
-
-          thread => $thread,
-
-          title => $headline,
-
-          body  => $body,
-
-          thread => $thread,
-
-          cat    => $cat,
-
-          attach => $sra,
-
-          format => $format,
-
-          id => $id,
-
-          user => $m_sUser,
-
-          attach => $m_sFilename,
-
-          ip => remote_addr(),
-
-
-     );
-
-     my $id = addMessage(\%message);
-
-=cut
-
-sub addMessage
-{
-    my ($self, @p) = getSelf(@_);
-    if ($self->checkFlood($p[0]->{ip})) {
-        my $thread = defined $p[0]->{thread} ? $p[0]->{thread} : 'trash';
-        $thread = ($thread =~ /^(\w{3,50})$/) ? $1 : 'trash';
-        $thread = $m_dbh->quote_identifier($thread);
-        my $headline = defined $p[0]->{title} ? $p[0]->{title} : 'headline';
-        $headline = ($headline =~ /^(.{3,100})$/) ? $1 : 'Invalid headline';
-        my $m_sUser   = defined $p[0]->{user}   ? $p[0]->{user}   : 'guest';
-        my $body      = defined $p[0]->{body}   ? $p[0]->{body}   : 'Body';
-        my $cat       = defined $p[0]->{cat}    ? $p[0]->{cat}    : 'news';
-        my $rght      = $self->catright($cat);
-        my $attach    = defined $p[0]->{attach} ? $p[0]->{attach} : 0;
-        my $format    = defined $p[0]->{format} ? $p[0]->{format} : 'bbcode';
-        my $m_sAction = defined $p[0]->{action} ? $p[0]->{action} : 'news';
-        my $sql       = "insert into $thread (`title`,`body`,`attach`,`cat`,`right`,`user`,`action`,`format`) values(?,?,?,?,?,?,?,?)";
-        my $sth       = $m_dbh->prepare($sql);
-        $sth->execute($headline, $body, $attach, $cat, $rght, $m_sUser, $m_sAction, $format) or warn $m_dbh->errstr;
-        my $id = $m_dbh->last_insert_id(undef, undef, qw(news news_id));
-        $sth->finish();
-        return $id;
-    } else {
-        return 0;
-    }
-}
-
-=head2 editMessage()
-
-     my %message = (
-
-          thread => $thread,
-
-          title => $headline,
-
-          body  => $body,
-
-          thread => $thread,
-
-          cat    => $cat,
-
-          attach => $sra,
-
-          format => $format,
-
-          id => $id,
-
-          user => $m_sUser,
-
-          attach => $m_sFilename,
-
-          ip => remote_addr(),
-
-     );
-
-     editMessage(\%message);
-
-=cut
-
-sub editMessage
-{
-    my ($self, @p) = getSelf(@_);
-    if ($self->checkFlood($p[0]->{ip})) {
-        my $thread = defined $p[0]->{thread} ? $p[0]->{thread} : 'trash';
-        $thread = ($thread =~ /^(\w{3,50})$/) ? $1 : 'trash';
-        $thread = $m_dbh->quote_identifier($thread);
-        my $refid    = defined $p[0]->{id}    ? $p[0]->{id}    : 1;
-        my $headline = defined $p[0]->{title} ? $p[0]->{title} : 'headline';
-        $headline = ($headline =~ /^(.{3,100})$/) ? $1 : 'Invalid headline';
-        my $m_sUser = defined $p[0]->{user}   ? $p[0]->{user}   : 'guest';
-        my $body    = defined $p[0]->{body}   ? $p[0]->{body}   : 'Body';
-        my $attach  = defined $p[0]->{attach} ? $p[0]->{attach} : 0;
-        my $format  = defined $p[0]->{format} ? $p[0]->{format} : 'bbcode';
-        my $cat     = defined $p[0]->{cat}    ? $p[0]->{cat}    : 'news';
-        my $up =
-          defined $p[0]->{uploadpath}
-          ? $p[0]->{uploadpath}
-          : '/srv/www/htdocs/downloads';
-
-        if ($attach ne '0.0') {
-            my $sql_insert = qq/update $thread set title =?, body =? , attach= ?,format =?,user =?,cat =?,`right` =? where id = ?;/;
-            my $sth        = $m_dbh->prepare($sql_insert);
-            $sth->execute($headline, $body, $attach, $format, $m_sUser, $cat, $self->catright($cat), $refid) or warn $m_dbh->errstr;
-            $sth->finish();
-        } else {
-            my $sql_insert = qq/update $thread set title =?, body = ? ,format = ?,user = ?,cat = ?,`right` =?  where id = ?;/;
-            my $sth        = $m_dbh->prepare($sql_insert);
-            $sth->execute($headline, $body, $format, $m_sUser, $cat, $self->catright($cat), $refid) or warn $m_dbh->errstr;
-            $sth->finish();
-        }
-    }
-}
-
-=head2 reply
-
-     my %reply =(
-
-          title => $headline,
-
-          body => $body,
-
-          id => $reply,
-
-          user => $m_sUser,
-
-          attach =>  $sra,
-
-          format => $html,
-
-          ip => remote_addr(),
-
-     );
-
-     reply(\%reply);
-
-=cut
-
-sub reply
-{
-    my ($self, @p) = getSelf(@_);
-    if ($self->checkFlood($p[0]->{ip})) {
-        my $headline = defined $p[0]->{title} ? $p[0]->{title} : 'headline';
-        $headline = ($headline =~ /^(.{3,100})$/) ? $1 : 'Invalid headline';
-        my $m_sUser = defined $p[0]->{user}   ? $p[0]->{user}   : 'guest';
-        my $body    = defined $p[0]->{body}   ? $p[0]->{body}   : 'Body';
-        my $attach  = defined $p[0]->{attach} ? $p[0]->{attach} : 0;
-        my $format  = defined $p[0]->{format} ? $p[0]->{format} : 'bbcode';
-        my $refid   = defined $p[0]->{id}     ? $p[0]->{id}     : 1;
-        my $sql     = "insert into replies (`title`,`body`,`attach`,`right`,`user`,`refererId`,`format`) values(?,?,?,?,?,?,?)";
-        my $sth     = $m_dbh->prepare($sql);
-        $sth->execute($headline, $body, $attach, $self->topicright($refid), $m_sUser, $refid, $format) or warn $m_dbh->errstr;
-        $sth->finish();
-    }
-}
-
-=head2 deleteMessage
-
-      $bool = $self->deleteMessage($table,$id);
-
-=cut
-
-sub deleteMessage
-{
-    my ($self, @p) = getSelf(@_);
-    my $p_sTable   = $p[0];
-    my $id         = $p[1];
-    my $sql_backup = "select * from $p_sTable  Where id  = '$id'";
-    my $sth_backup = $m_dbh->prepare($sql_backup);
-    $sth_backup->execute();
-    my $backup    = $sth_backup->fetchrow_hashref();
-    my $c         = ($p_sTable eq 'replies') ? 'replies' : $backup->{cat};
-    my $refererId = ($p_sTable eq 'replies') ? $backup->{refererId} : 0;
-    my $sql_trash = "insert into `trash`  (`table`,`oldId`,`title`,`body`,`date`,`user`,`right`,`attach`,`cat`,`sticky`,`refererId`,`format`) values(?,?,?,?,?,?,?,?,?,?,?)";
-    my $sth_trash = $m_dbh->prepare($sql_trash);
-    $sth_trash->execute($p_sTable, $id, $backup->{title}, $backup->{body}, $backup->{date}, $backup->{user}, $backup->{right}, $backup->{attach}, $c, $backup->{sticky}, $refererId, $backup->{format});
-    my $sql_delete = "DELETE FROM $p_sTable Where id  = '$id'";
-    my $sth        = $m_dbh->prepare($sql_delete);
-    $sth->execute() or warn $m_dbh->errstr;
-    $sth->finish();
-    return 1;
-}
-
-=head2 readMenu()
-
-      @menu = $m_oDatabase->readMenu($sThread,$nRight,$nStart,$nEnd,$bRewrite);
-
-=cut
-
-sub readMenu
-{
-    my ($self, @p) = getSelf(@_);
-    my $thread   = $p[0];
-    my $p_nRight = $p[1];
-    my $p_nStart = $p[2];
-    my $p_nEnd   = $p[3];
-    my $rewrite  = $p[4];
-    $p_nStart = 0  unless (defined $p_nStart);
-    $p_nEnd   = 10 unless (defined $p_nEnd);
-    my $limit = $p_nEnd - $p_nStart;
-    $rewrite = 0 unless (defined $rewrite);
-    my $sql_read = qq/select title,id from  $thread where `right` <= $p_nRight order by date desc  LIMIT $p_nStart , $limit/;
-    my $sth      = $m_dbh->prepare($sql_read);
-    $sth->execute();
-    my @output;
-
-    while (my @data = $sth->fetchrow_array()) {
-        my $headline = $data[0];
-        my $id       = $data[1];
-        $headline =~ s/(.{15}).+/$1.../;
-        my $nl =
-          ($rewrite)
-          ? "/$p_nStart/$p_nEnd/$thread.html#$id"
-          : "$ENV{SCRIPT_NAME}?action=$thread&amp;von=$p_nStart&amp;bis=$p_nEnd#$id";
-        push @output,
-          {
-            text => $headline,
-            href => $nl,
-          };
-    }
-    $sth->finish();
-    return @output;
-}
-
-=head2 rss()
-
-      $rss = $m_oDatabase->rss($thread,int start);
-
-=cut
-
-sub rss
-{
-    my ($self, @p) = getSelf(@_);
-    my $thread = $p[0];
-    $thread = 'news' unless (defined $thread);
-    my $p_nStart = $p[1];
-    $p_nStart = 0 unless (defined $p_nStart);
-    my $time     = localtime;
-    my $sql_read = qq/select *from  $thread  where `right` = '0' order by id desc  LIMIT $p_nStart , 10/;
-    my $sth      = $m_dbh->prepare($sql_read);
-    $sth->execute();
-    my @output;
-    push @output,
-qq(Content-Type: text/rss\n\n<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns="http://my.netscape.com/rdf/simple/0.9/"><channel><title>$thread</title>\n<description>Die Topics als rss.</description>\n<link>$m_sServerName</link>\n<language>de</language>\n<pubDate>$time</pubDate>\n</channel>\n);
-
-    while (my @data = $sth->fetchrow_array()) {
-        my $headline = $data[0];
-        my $href     = $data[9];
-        my $link =
-          $mod_rewrite
-          ? "$m_sServerName/$thread.html#$href"
-          : "$m_sServerName?action=$thread;#$href";
-        push @output, "\n<item>\n<title>$headline</title>\n<link>$link</link>\n</item>\n";
-    }
-    push @output, "\n</rdf:RDF>";
-    $sth->finish();
-    return @output;
-}
-
 =head2 getName()
 
       $name = $m_oDatabase->getName($m_sSid);
@@ -590,21 +330,6 @@ sub addUser
     return 1 if ($anzahl + 0 == 1);
 }
 
-=head2 rewrite()
-
-enable or disable rewrite.
-
-=cut
-
-sub rewrite
-{
-    my ($self, @p) = getSelf(@_);
-    if (defined $p[0]) {
-        if ($p[0] =~ /(0|1)/) {$mod_rewrite = $1;}
-    } else {
-        return $mod_rewrite;
-    }
-}
 
 =head2 serverName()
 
@@ -632,122 +357,6 @@ sub floodtime
     else               {return $m_nSecs;}
 }
 
-=head2 searchDB()
-
-       searchDB($query,$column,$table,$rigt,$start,$end);
-
-regexp search in tabelle ...
-
-=cut
-
-sub searchDB
-{
-    my ($self, @p) = getSelf(@_);
-    my $p_sQuery = $p[0];
-    eval("return 0 if/($p_sQuery)/;");
-    return "Invalid regexp : $@" if $@;
-    $p_sQuery = $self->quote($p_sQuery);
-    my $p_sCol = $p[1];
-    $p_sCol = $m_dbh->quote_identifier($p_sCol);
-    my $p_sTable = $p[2];
-    $p_sTable = $m_dbh->quote_identifier($p_sTable);
-    my $p_nRight = $p[3];
-    my $p_nStart = $p[4] ? $p[4] : 0;
-    my $p_nEnd   = $p[5] ? $p[5] : 100;
-    my $limit    = $p_nEnd - $p_nStart;
-    $p_nRight = $p_nRight =~ /(\d+)/ ? $1 : 0;
-    $p_nStart = $p_nStart =~ /(\d+)/ ? $1 : 0;
-    $limit    = $limit    =~ /(\d+)/ ? $1 : 10;
-    my $sql_select = "SELECT * FROM $p_sTable WHERE  `right` <= $p_nRight  && ( $p_sCol REGEXP $p_sQuery || title REGEXP $p_sQuery )  order by date desc LIMIT $p_nStart , $limit ";
-    my $b          = '<table align="center" summary="layoutSearch" border="0" cellpadding="0" cellspacing="0" width="100%"><tr><td class="caption">Title</td><td class="caption">User</td><td class="caption">Datum</td></tr>';
-    my @messages   = $self->fetch_AoH($sql_select);
-
-    for (my $i = 0; $i <= $#messages; $i++) {
-        my $body = $messages[$i]->{body};
-        if (!utf8::is_utf8($body)) {
-            utf8::decode($body);
-        }
-        $body =~ s/\[([^\]])+\]//gs;
-        $body =~ s?<[^>]+>??gs;
-        my $j = index $body, /$p[0]/;
-        $j = $j > 50 ? $j - 50 : 0;
-        $body = substr($body, $j, 150);
-        $body = encode_entities($body);
-        $body =~ s?($p[0])?<span style="color:red;">$1</span>?ig;
-
-        if (!utf8::is_utf8($messages[$i]->{title})) {
-            utf8::decode($messages[$i]->{title});
-        }
-        $messages[$i]->{title} = encode_entities($messages[$i]->{title});
-        $messages[$i]->{title} =~ s?($p[0])?<span style="color:red;">$1</span>?ig;
-
-        my $link =
-          ($mod_rewrite)
-          ? "/showMessage$messages[$i]->{id}.html"
-          : "$ENV{SCRIPT_NAME}?action=showMessage&amp;reply=$messages[$i]->{id}";
-        $b .=
-qq(<tr><td class="values"><a href="$link" class="menuLink">$messages[$i]->{title}</a></td><td class="values">$messages[$i]->{user}</td><td align="right" class="values"><font size="-1">$messages[$i]->{date}</font></td></tr><tr><td colspan="3"><font size="-2">$body</font></td></tr>);
-    }
-    $b .= '</table>';
-    return $b;
-}
-
-=head2 fulltext()
-
-      @messages = fulltext(query,table);
-
-fulltextsuche in tabelle ...
-
-=cut
-
-sub fulltext
-{
-    my ($self, @p) = getSelf(@_);
-    my $p_sQuery = $p[0];
-    eval("return 0 if/($p_sQuery)/;");
-    return "Invalid Query : <br/>" if $@;
-    $p_sQuery = $self->quote($p_sQuery);
-    my $p_sTable = $p[1];
-    $p_sTable = $m_dbh->quote_identifier($p_sTable);
-    my $p_nRight = $p[2];
-    my $p_nStart = $p[3] ? $p[3] : 0;
-    my $p_nEnd   = $p[4] ? $p[4] : 100;
-    my $limit    = $p_nEnd - $p_nStart;
-    $p_nRight = $p_nRight =~ /(\d+)/ ? $1 : 0;
-    $p_nStart = $p_nStart =~ /(\d+)/ ? $1 : 0;
-    $limit    = $limit    =~ /(\d+)/ ? $1 : 10;
-    my $b        = '<table align="center" summary="fulltext" border="0" cellpadding="2" cellspacing="0" width="100%"><tr><td class="caption">Title</td><td class="caption">User</td><td class="caption">Datum</td></tr>';
-    my @messages = $self->fetch_AoH("SELECT * FROM $p_sTable  where `right` <= $p_nRight and MATCH (title,body) AGAINST($p_sQuery) order by date desc LIMIT $p_nStart , $limit");
-
-    for (my $i = 0; $i <= $#messages; $i++) {
-        my $body = $messages[$i]->{body};
-        if (!utf8::is_utf8($body)) {
-            utf8::decode($body);
-        }
-        $body =~ s/\[([^\]])+\]//gs;
-        $body =~ s?<[^>]+>??gs;
-        my $j = index $body, $p_sQuery;
-        $j = $j > 50 ? $j - 50 : 0;
-        $body = substr($body, $j, 150);
-        $body = encode_entities($body);
-        $body =~ s/($p[0])/<span style="color:red;">$1<\/span>/ig;
-
-        if (!utf8::is_utf8($messages[$i]->{title})) {
-            utf8::decode($messages[$i]->{title});
-        }
-        $messages[$i]->{title} = encode_entities($messages[$i]->{title});
-        $messages[$i]->{title} =~ s/($p[0])/<span style="color:red;">$1<\/span>/ig;
-        my $link =
-          ($mod_rewrite)
-          ? "/showMessage$messages[$i]->{id}.html"
-          : "$ENV{SCRIPT_NAME}?action=showMessage&amp;reply=$messages[$i]->{id}";
-        $b .=
-qq(<tr><td class="values"><a href="$link" class="menuLink">$messages[$i]->{title}</a></td><td class="values">$messages[$i]->{user}</td><td align="right" class="values"><font size="-1">$messages[$i]->{date}</font></td></tr><tr><td colspan="3"><font size="-2">$body</font></td></tr>);
-    }
-    $b .= '</table>';
-    return $b;
-}
-
 =head2 checkFlood
 
 checked wann die letzte aktion der ip adresse war und
@@ -874,7 +483,7 @@ sub GetDataBases
 {
     my ($self, @p) = getSelf(@_);
     my $name = $p[0] ? shift(@p) : 'm_ChangeCurrentDb';
-    my $change = $p[0] ? 'onchange="this.form.submit()"' : '';
+    my $change = $p[0] ? 'onchange="submitForm(this.form)"' : '';
     my $m_sCurrentDb = $self->CurrentDb();
     my @dbs          = $self->fetch_array('show Databases');
     my $return       = qq|<select align="center" $change name="$name" style="width:75%" >|;
@@ -1196,6 +805,7 @@ sub GetCollation
     my ($self, @p) = getSelf(@_);
     my $name      = shift @p;
     my $selected  = shift @p;
+    no warnings; #$selected maybe empty
     my @collation = $self->fetch_AoH("SHOW COLLATION");
     if ($name) {
         my @a = $self->fetch_AoH("SHOW TABLE STATUS");
@@ -1256,8 +866,7 @@ sub GetAttrs
              ? 'selected="selected"'
              : ''
           )
-          . q|>UNSIGNED</option>
-    <option  value="UNSIGNED ZEROFILL" |
+          . q|>UNSIGNED</option><option  value="UNSIGNED ZEROFILL" |
           . (
              $hr->{'Create Table'} =~ /$select[^,]+unsigned zerofill/
              ? 'selected="selected"'
@@ -1361,7 +970,7 @@ sub fetch
 =head1 SEE ALSO
 
 L<MySQL::Admin::GUI> L<DBI> L<DBI::Library>
-
+"
 =head1 AUTHOR
 
 Dirk Lindner <lze@cpan.org>
