@@ -8,19 +8,20 @@ use vars qw(
   $DefaultClass
   @EXPORT
   @ISA
-  $m_hrAction
+  $action
   $length
-  $m_nStart
-  $m_sStyle
+  $nStart
+  $sStyle
   $mod_rewrite
   $append
   $pages
   $path
   $per_page
+  $bAjax
 );
 @HTML::Menu::Pages::EXPORT  = qw(makePages);
 @ISA                        = qw(Exporter);
-$HTML::Menu::Pages::VERSION = '0.62';
+$HTML::Menu::Pages::VERSION = '0.65';
 $DefaultClass               = 'HTML::Menu::Pages' unless defined $HTML::Menu::Pages::DefaultClass;
 
 =head1 NAME
@@ -39,7 +40,7 @@ use HTML::Menu::Pages;
 
                         length => '345',
 
-                        style => 'lze',
+                        style => 'mysql',
 
                         mod_rewrite => 0,
 
@@ -61,7 +62,7 @@ use HTML::Menu::Pages;
 
                 length => '345',
 
-                style => 'lze',
+                style => 'mysql',
 
                 mod_rewrite => 0,
 
@@ -116,15 +117,16 @@ sub makePages
 {
     my ($self, @p) = getSelf(@_);
     my $hashref = $p[0];
-    $m_hrAction  = $hashref->{action};
-    $m_nStart    = $hashref->{start} > 0 ? $hashref->{start} : 0;
-    $m_sStyle    = $hashref->{style};
+    $action  = $hashref->{action};
+    $nStart    = $hashref->{start} > 0 ? $hashref->{start} : 0;
+    $sStyle    = $hashref->{style};
     $mod_rewrite = $hashref->{mod_rewrite} ? $hashref->{mod_rewrite} : 0;
     $append      = $hashref->{append} ? $hashref->{append} : '';
     $length      = $hashref->{length} ? $hashref->{length} : 0;
     $pages       = $hashref->{title} ? $hashref->{title} : "Start: ";
     $path        = $hashref->{path} ? $hashref->{path} : 'cgi-bin/';
     $per_page    = $hashref->{links_pro_page} ? $hashref->{links_pro_page} : 10;
+    $bAjax     = $hashref->{ajax} ? $hashref->{ajax} : 0;
     $self->ebis() if ($length > $per_page);
 }
 
@@ -137,12 +139,12 @@ private
 sub ebis
 {
     my ($self, @p) = getSelf(@_);
-    my $previousPage = (($m_nStart - $per_page) > 0) ? $m_nStart - $per_page : 0;
-    my $nextPage = $m_nStart;
+    my $previousPage = (($nStart - $per_page) > 0) ? $nStart - $per_page : 0;
+    my $nextPage = $nStart;
     $nextPage = $per_page if ($previousPage <= 0);
     my %template = (
                     path     => "$path/templates",
-                    style    => $m_sStyle,
+                    style    => $sStyle,
                     template => "pages.htm",
                     name     => 'pages'
     );
@@ -151,22 +153,18 @@ sub ebis
                  name  => 'header',
                  pages => '<a class ="menuLink3" href="'
                    . (
-                      $mod_rewrite
-                      ? "/$m_hrAction.html&amp;$append"
-                      : "$ENV{SCRIPT_NAME}?action=$m_hrAction&amp;$append"
+                      "javascript:requestURI('$ENV{SCRIPT_NAME}?action=$action&ajax=true&$append','$action','$action')"
                    )
                    . '">'
                    . $pages . '</a>',
                 },
     );
     push @data,
-      {
+      { 
         name => "previous",
-        href => $mod_rewrite
-        ? "/$previousPage/$nextPage/$m_hrAction.html&amp;$append"
-        : "$ENV{SCRIPT_NAME}?von=$previousPage&amp;bis=$nextPage&amp;action=$m_hrAction&amp;$append",
+        href => "javascript:requestURI('$ENV{SCRIPT_NAME}?von=$previousPage&bis=$nextPage&action=$action&ajax=true&$append','$action','$action')",
       }
-      if ($m_nStart - $per_page >= 0);
+      if ($nStart - $per_page >= 0);
     my $sites = 1;
 
     if ($length > 1) {
@@ -176,12 +174,12 @@ sub ebis
             $sites = (int($length / $per_page) + 1) * 10;
         }
     }
-    my $beginn = $m_nStart / $per_page;
-    $beginn = (int($m_nStart / $per_page) + 1) * 10 unless ($m_nStart % $per_page == 0);
+    my $beginn = $nStart / $per_page;
+    $beginn = (int($nStart / $per_page) + 1) * 10 unless ($nStart % $per_page == 0);
     $beginn = 0 if ($beginn < 0);
     my $b = ($sites >= 10) ? $beginn : 0;
     $b = ($beginn - $per_page >= 0) ? $beginn - $per_page : 0;
-    my $h1 = (($m_nStart - ($per_page * 5)) / $per_page);
+    my $h1 = (($nStart - ($per_page * 5)) / $per_page);
     $b = $h1 if ($h1 > 0);
     my $m_nEnd = ($sites >= 10) ? $b + $per_page : $sites;
     $b      = int($b);
@@ -191,31 +189,26 @@ sub ebis
         my $c = $b * $per_page;
         my $d = $c + $per_page;
         $d = $length if ($d > $length);
-        my $svbis =
-          ($mod_rewrite)
-          ? "/$c/$d/$m_hrAction.html&amp;$append"
-          : "$ENV{SCRIPT_NAME}?von=$c&amp;bis=$d&amp;action=$m_hrAction&amp;$append";
-        push @data, ($b * $per_page eq $m_nStart)
+        my $svbis = "javascript:requestURI('$ENV{SCRIPT_NAME}?von=$c&bis=$d&action=$action&ajax=true&$append','$action','$action')" ;
+        push @data, ($b * $per_page eq $nStart)
           ? {
              name  => 'currentLinks',
              href  => $svbis,
-             title => $b + 1
+             title => $b + 1,
           }
           : {
              name  => 'links',
              href  => $svbis,
-             title => $b + 1
+             title => $b + 1,
           };
         last if ($d eq $length);
         $b++;
     }
-    my $v    = $m_nStart + $per_page;
+    my $v    = $nStart + $per_page;
     my $next = $v + $per_page;
     $next = $length if ($next > $length);
-    my $esvbis =
-      ($mod_rewrite)
-      ? "/$v/$next/$m_hrAction.html&amp;$append"
-      : "$ENV{SCRIPT_NAME}?von=$v&amp;bis=$next&amp;action=$m_hrAction&amp;$append";
+    my $esvbis = "javascript:requestURI('$ENV{SCRIPT_NAME}?von=$v&bis=$next&action=$action&ajax=true&$append','$action','$action')";
+#     :" $ENV{SCRIPT_NAME}?von=$v&amp;bis=$next&amp;action=$action&amp;$append";
     push @data,
       {
         name => "next",
@@ -241,7 +234,7 @@ sub getSelf
 
 =head1 AUTHOR
 
-Dirk Lindner <lze@cpan.org>
+Dirk Lindner <dirk.lze@gmail.com>
 
 
 =head2 see Also
@@ -251,7 +244,7 @@ L<CGI> L<MySQL::Admin::GUI> L<MySQL::Admin::Actions> L<MySQL::Admin::Translate>
 
 =head1 LICENSE
 
-Copyright (C) 2005 - 2008 by Hr. Dirk Lindner
+Copyright (C) 2005 - 2015 by Hr. Dirk Lindner
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public License
