@@ -6,7 +6,7 @@ use vars qw($m_hrActions $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Actions::EXPORT = qw(loadActions saveActions $m_hrActions);
 use MySQL::Admin::Config;
 @MySQL::Admin::Actions::ISA     = qw( Exporter MySQL::Admin::Config);
-$MySQL::Admin::Actions::VERSION = '0.62';
+$MySQL::Admin::Actions::VERSION = '0.65';
 $DefaultClass                   = 'MySQL::Admin::Actions' unless defined $MySQL::Admin::Actions::DefaultClass;
 $defaultconfig                  = '%CONFIG%';
 
@@ -34,7 +34,7 @@ MySQL::Admin::Actions - actions for Mysql::Admin
 
                         },
         };
-        saveActions(); # stored into %CONFIG%
+        saveActions();
 
 actions
 
@@ -97,7 +97,7 @@ sub getSelf
 
 =head2 see Also
 
-L<CGI> L<MySQL::Admin::Actions> L<MySQL::Admin::Translate> L<MySQL::Admin::Settings> L<MySQL::Admin::Config>
+L<MySQL::Admin> L<MySQL::GUI> L<MySQL::Admin::Actions> L<MySQL::Admin::Translate> L<MySQL::Admin::Settings> L<MySQL::Admin::Config>
 
 =head1 AUTHOR
 
@@ -105,7 +105,7 @@ Dirk Lindner <lze@cpan.org>
 
 =head1 LICENSE
 
-Copyright (C) 2005-2009 by Hr. Dirk Lindner
+Copyright (C) 2005-2015 by Hr. Dirk Lindner
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public License
