@@ -3,7 +3,7 @@ use Template::Quick;
 use strict;
 use warnings;
 require Exporter;
-use vars qw($DefaultClass @EXPORT  @ISA  $login $m_nRight $htmlright $template $zoom $query);
+use vars qw($DefaultClass @EXPORT  @ISA  $login $m_nRight $htmlright $ajax $template $zoom $query $maxlength);
 our $m_sStyle = 'lze';
 our $m_sTitle = '';
 our $m_nSize  = 16;
@@ -11,7 +11,7 @@ our $server;
 @MySQL::Admin::Main::EXPORT_OK   = qw(all initMain Header Footer);
 %MySQL::Admin::Main::EXPORT_TAGS = ('all' => [qw(initMain Header Footer)]);
 @MySQL::Admin::Main::ISA         = qw( Exporter Template::Quick);
-$MySQL::Admin::Main::VERSION     = '0.62';
+$MySQL::Admin::Main::VERSION     = '0.65';
 $DefaultClass                    = 'MySQL::Admin::Main' unless defined $MySQL::Admin::Main::DefaultClass;
 
 =head1 NAME
@@ -80,9 +80,11 @@ sub initMain
     $zoom      = defined $hash->{zoom} ? $hash->{zoom} : '';
     $query     = defined $hash->{query} ? $hash->{query} : '';
     $login     = defined $hash->{login} ? $hash->{login} : '';
+    $maxlength = defined $hash->{maxlength} ? $hash->{maxlength} : 1000;
     $m_nRight  = defined $hash->{right} ? $hash->{right} : 0;
     $htmlright = defined $hash->{htmlright} ? $hash->{htmlright} : 2;
     $template  = defined $hash->{template} ? $hash->{template} : "index.htm";
+    $ajax = defined $hash->{ajax} ? $hash->{ajax} : "false";
     my %template = (
                     path     => $hash->{path},
                     style    => $m_sStyle,
@@ -109,6 +111,8 @@ sub Header
                   htmlright => $htmlright,
                   zoom      => $zoom,
                   query     => $query,
+                  maxlength => $maxlength,
+                  ajax => $ajax,
     );
     $self->SUPER::appendHash(\%header);
 }
@@ -146,11 +150,11 @@ sub getSelf
 
 =head1 AUTHOR
 
-Dirk Lindner <lze@cpan.org>
+Dirk Lindner <dirk.lze@gmail.com
 
 =head1 LICENSE
 
-Copyright (C) 2005-2009 by Hr. Dirk Lindner
+Copyright (C) 2005-2015 by Hr. Dirk Lindner
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public License
