@@ -6,7 +6,7 @@ use vars qw( $session $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Session::EXPORT = qw(loadSession saveSession $session);
 use MySQL::Admin::Config;
 @MySQL::Admin::Session::ISA     = qw(Exporter MySQL::Admin::Config);
-$MySQL::Admin::Session::VERSION = '0.62';
+$MySQL::Admin::Session::VERSION = '0.65';
 $DefaultClass                   = 'MySQL::Admin::Session' unless defined $MySQL::Admin::Session::DefaultClass;
 $defaultconfig                  = '%CONFIG%';
 
@@ -16,7 +16,7 @@ MySQL::Admin::Session - store the sessions for MySQL::Admin
 
 =head1 SYNOPSIS
 
-see l<MySQL::Admin>
+see l<MySQL::Admin::Config>
 
 =head1 DESCRIPTION
 
@@ -78,11 +78,15 @@ sub getSelf
 
 =head1 AUTHOR
 
-Dirk Lindner <lze@cpan.org>
+Dirk Lindner <dirk.lze@gmail.com>
+
+=head2 see Also
+
+L<MySQL::Admin> L<MySQL::GUI> L<MySQL::Admin::Actions> L<MySQL::Admin::Translate> L<MySQL::Admin::Settings> L<MySQL::Admin::Config>
 
 =head1 LICENSE
 
-Copyright (C) 2005-2009 by Hr. Dirk Lindner
+Copyright (C) 2005-2015 by Hr. Dirk Lindner
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public License
