@@ -6,7 +6,7 @@ use vars qw($ACCEPT_LANGUAGE $lang $DefaultClass @EXPORT  @ISA $defaultconfig);
 @MySQL::Admin::Translate::EXPORT = qw(loadTranslate saveTranslate $lang);
 use MySQL::Admin::Config;
 @ISA                              = qw(Exporter MySQL::Admin::Config);
-$MySQL::Admin::Translate::VERSION = '0.62';
+$MySQL::Admin::Translate::VERSION = '0.65';
 $DefaultClass                     = 'MySQL::Admin::Translate' unless defined $MySQL::Admin::Translate::DefaultClass;
 $defaultconfig                    = '%CONFIG%';
 
@@ -86,15 +86,15 @@ sub getSelf
 
 =head2 see Also
 
-L<CGI> L<MySQL::Admin> L<MySQL::Admin::Actions> L<MySQL::Admin::Translate> L<MySQL::Admin::Settings> L<MySQL::Admin::Config>
+L<MySQL::Admin> L<MySQL::GUI> L<MySQL::Admin::Actions> L<MySQL::Admin::Translate> L<MySQL::Admin::Settings> L<MySQL::Admin::Config>
 
 =head1 AUTHOR
 
-Dirk Lindner <lze@cpan.org>
+Dirk Lindner <dirk.lze@gmail.com>
 
 =head1 LICENSE
 
-Copyright (C) 2009 by Hr. Dirk Lindner
+Copyright (C) 2015 by Hr. Dirk Lindner
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public License
