@@ -4,15 +4,15 @@ use utf8;
 use warnings;
 use MySQL::Admin qw(init translate);
 require Exporter;
-use vars qw($defaultconfig $tmp $DefaultClass @EXPORT_OK @ISA $m_sStyle $m_bMod_perl);
+use vars qw($defaultconfig $tmp $DefaultClass @EXPORT_OK @ISA $sStyle $bModPerl);
 @ISA                          = qw(Exporter);
 @Template::Quick::EXPORT      = qw(initTemplate appendHash Template initArray);
 %Template::Quick::EXPORT_TAGS = ('all' => [qw(initTemplate appendHash Template initArray  )]);
-$Template::Quick::VERSION     = '0.62';
+$Template::Quick::VERSION     = '0.65';
 $DefaultClass                 = 'Template::Quick' unless defined $Template::Quick::DefaultClass;
 our %tmplate;
-$m_sStyle      = 'lze';
-$m_bMod_perl   = ($ENV{MOD_PERL}) ? 1 : 0;
+$sStyle      = 'mysql';
+$bModPerl   = ($ENV{MOD_PERL}) ? 1 : 0;
 $defaultconfig = '%CONFIG%';
 
 =head1 NAME
@@ -97,12 +97,12 @@ sub initTemplate
     my $hash = $p[0];
     $DefaultClass = $self;
     my $configfile = defined $hash->{config} ? $hash->{config} : $defaultconfig;
-    init($configfile) unless $m_bMod_perl;
+    init($configfile) unless $bModPerl;
     use Fcntl qw(:flock);
     use Symbol;
     my $fh = gensym;
-    $m_sStyle = $hash->{style} if defined $hash->{style};
-    my $m_sFile = "$hash->{path}/$m_sStyle/$hash->{template}";
+    $sStyle = $hash->{style} if defined $hash->{style};
+    my $m_sFile = "$hash->{path}/$sStyle/$hash->{template}";
     open $fh, "$m_sFile" or warn "$!: $m_sFile";
     seek $fh, 0, 0;
     my @lines = <$fh>;
